from functools import partial

class CommonClient(object):

    def __init__(self, data_pro):
        self.data_pro = data_pro

    def query(self,api_name,**kwargs):
        return self.data_pro.get_rainiee_client().query(api_name, 'POST', req_param = kwargs)

    def __getattr__(self, name):
        return partial(self.query, api_name=name)


# !/usr/bin/env python
# -*- coding: utf-8 -*-
import json
from functools import partial
import requests

from rainiee_data_test.utils import upass


class DataApi:
    def __init__(self, token=None, timeout=6000):
        """
        Parameters
        ----------
        token: str
            API接口TOKEN，用于用户认证
        """
        self.__timeout = timeout
        self.__http_url = upass.get_host() + '/api/v1.0/{}'
        self.__token = token

    def query(self, api_name, method_type, req_param):
        headers = {
            'Authorization': 'JWT ' + self.__token,
            'Connection': 'close'
        }
        if method_type == 'POST':
            res = requests.post(self.__http_url.format(api_name), data=req_param, timeout=self.__timeout,
                                headers=headers)
        else:
            res = requests.get(self.__http_url.format(api_name), params=req_param, timeout=self.__timeout,
                               headers=headers)
        return json.loads(res.text)

    def __getattr__(self, name):
        return partial(self.query, api_name=name)



import json

import requests

from rainiee_data_test.utils import upass


class LoginApi:
    def __init__(self, username, password, timeout=15):
        self.__timeout = timeout
        self.__username = username
        self.__password = password
        self.__login_url = upass.get_host() + '/api/v1.0/api-token-auth'

    def login(self):
        res = requests.get(self.__login_url, params={'username': self.__username, 'password': self.__password},
                           timeout=self.__timeout)
        result = json.loads(res.text)
        if result['code'] == 200:
            return result['data']
        raise Exception(result['message'])



#!/usr/bin/python
# -*- coding: UTF-8 -*-

from rainiee_data_test.pro import data_pro


def cn_stock_eod(symbol, start_index, end_index):
    return data_pro.get_rainiee_client().cn_stock_eod(method_type='GET', req_param={
        'symbol': symbol,
        'start_index': start_index,
        'end_index': end_index
    })


def cn_stock_realtime(symbol):
    return data_pro.get_rainiee_client().cn_stock_realtime(method_type='GET', req_param={
        'symbol': symbol
    })



#!/usr/bin/python
# -*- coding: UTF-8 -*-
from rainiee_data_test.pro import data_pro


def na_etf_eod(symbol, start_date, end_date):
    return data_pro.get_rainiee_client().na_etf_eod(method_type='GET', req_param={
        'symbol': symbol,
        'start_date': start_date if isinstance(start_date, str) else start_date.strftime('%Y%m%d'),
        'end_date': end_date if isinstance(end_date, str) else end_date.strftime('%Y%m%d')
    })


def na_etf_symbol(category):
    return data_pro.get_rainiee_client().na_etf_symbol(method_type='GET', req_param={
        'category': category
    })



#!/usr/bin/python
# -*- coding: UTF-8 -*-
from rainiee_data_test.pro import data_pro


def cn_index_eod(index_code, start_index, end_index):
    return data_pro.get_rainiee_client().cn_index_eod(method_type='GET', req_param={
        'index_code': index_code,
        'start_index': start_index,
        'end_index': end_index
    })


def cn_index_composition(index_code):
    return data_pro.get_rainiee_client().cn_index_composition(method_type='GET', req_param={
        'index_code': index_code
    })


def cn_index_composition_weight(index_code):
    return data_pro.get_rainiee_client().cn_index_composition_weight(method_type='GET', req_param={
        'index_code': index_code
    })


def cn_index_basic(market):
    return data_pro.get_rainiee_client().cn_index_basic(method_type='GET', req_param={
        'market': market
    })


def cn_symbol_list(category):
    return data_pro.get_rainiee_client().cn_symbol_list(method_type='GET', req_param={
        'category': category
    })



#!/usr/bin/python
# -*- coding: UTF-8 -*-
from rainiee_data_test.pro import data_pro


def trade_get_index(date):
    return data_pro.get_rainiee_client().trade_get_index(method_type='GET', req_param={'date': date if isinstance(date, str) else date.strftime('%Y%m%d')})


def trade_get_date(index):
    return data_pro.get_rainiee_client().trade_get_date(method_type='GET', req_param={
        'index': index
    })



# -*- coding:utf-8 -*-
from rainiee_data_test.pro import client, login
from rainiee_data_test.utils import upass


def init_token(username=None, password=None):
    set_token(login.LoginApi(username, password).login())


def get_token():
    return upass.get_token()


def set_token(token):
    upass.set_token(token)


def get_rainiee_client():
    """
    get rainiee data client
    """
    return client.DataApi(upass.get_token())


def pro_bar(api_name=None, method_type='GET', req_param=None, api=None):
    api = api if api is not None else get_rainiee_client()
    return api.query(api_name, method_type, req_param)



# -*- coding:utf-8 -*-
import os
TOKEN_F_P = 'rainiee_data.token'


def set_token(token):
    user_home = os.path.expanduser('~')
    path = os.path.join(user_home, TOKEN_F_P)
    with open(path, 'w') as f:
        f.write(token)


def get_token():
    user_home = os.path.expanduser('~')
    path = os.path.join(user_home, TOKEN_F_P)
    with open(path, 'r') as f1:
        return f1.readline()


def get_host():
    return 'http://localhost:8001'


import json
import rainiee_data_test.pro.data_pro as data_pro
from rainiee_data_test.common_client import CommonClient


class DataClient(object):

    def __init__(self, username, password):
        data_pro.init_token(username, password)

    def data_pro(self):
        return data_pro

    def get_token(self):
        return data_pro.get_token()

    def vip_channel(self):
        return CommonClient(data_pro)

    @staticmethod
    def cn_stock_realtime(symbol):
        return data_pro.pro_bar(api_name='cn_stock_realtime', method_type='GET', req_param={'symbol': symbol})

    @staticmethod
    def cn_stock_eod(symbol, start_index, end_index, adj=None, frequency='d'):
        return data_pro.pro_bar(api_name='cn_stock_eod', method_type='GET',
                                req_param={'symbol': symbol, 'start_index': start_index, 'end_index': end_index,
                                           'adj': adj, 'frequency': frequency})

    @staticmethod
    def cn_index_eod(index_code, start_index, end_index):
        return data_pro.get_rainiee_client().cn_index_eod(method_type='GET', req_param={
            'index_code': index_code,
            'start_index': start_index,
            'end_index': end_index
        })

    @staticmethod
    def cn_index_composition(index_code):
        return data_pro.get_rainiee_client().cn_index_composition(method_type='GET', req_param={
            'index_code': index_code
        })

    @staticmethod
    def cn_index_composition_weight(index_code):
        return data_pro.get_rainiee_client().cn_index_composition_weight(method_type='GET', req_param={
            'index_code': index_code
        })

    @staticmethod
    def cn_index_basic(market):
        return data_pro.get_rainiee_client().cn_index_basic(method_type='GET', req_param={
            'market': market
        })

    @staticmethod
    def cn_symbol_list(category):
        return data_pro.get_rainiee_client().cn_symbol_list(method_type='GET', req_param={
            'category': category
        })

    @staticmethod
    def na_etf_eod(symbol, start_date, end_date):
        return data_pro.get_rainiee_client().na_etf_eod(method_type='GET', req_param={
            'symbol': symbol,
            'start_date': start_date if isinstance(start_date, str) else start_date.strftime('%Y%m%d'),
            'end_date': end_date if isinstance(end_date, str) else end_date.strftime('%Y%m%d')
        })

    @staticmethod
    def na_etf_symbol(category):
        return data_pro.get_rainiee_client().na_etf_symbol(method_type='GET', req_param={
            'category': category
        })

    @staticmethod
    def cn_stockstats_latest_returns(symbol, gap=1):
        return data_pro.get_rainiee_client().cn_stockstats_latest_returns(method_type='GET', req_param={
            'symbol': symbol,
            'gap': gap
        })

    @staticmethod
    def cn_stockstats_returns(symbol, start_index, end_index):
        return data_pro.get_rainiee_client().cn_stockstats_returns(method_type='GET', req_param={
            'symbol': symbol,
            'start_index': start_index,
            'end_index': end_index
        })

    @staticmethod
    def cn_stockstats_list(symbol, start_index, end_index):
        return data_pro.get_rainiee_client().cn_stockstats_list(method_type='GET', req_param={
            'symbol': symbol,
            'start_index': start_index,
            'end_index': end_index
        })

    @staticmethod
    def cn_stockstats_sort(column, start_index, end_index):
        return data_pro.get_rainiee_client().cn_stockstats_sort(method_type='GET', req_param={
            'column': column,
            'start_index': start_index,
            'end_index': end_index
        })

    @staticmethod
    def cn_stockstats_eod_portf_return(portf, hold_index):
        return data_pro.get_rainiee_client().cn_stockstats_eod_portf_return(method_type='POST', req_param={
            'portf': json.dumps(portf),
            'hold_index': hold_index
        })

    @staticmethod
    def cn_stockstats_is_enter_market(index, return_metric, calc_period):
        return data_pro.get_rainiee_client().cn_stockstats_is_enter_market(method_type='GET', req_param={
            'index': index,
            'return_metric': return_metric,
            'calc_period': calc_period
        })

    @staticmethod
    def cn_stockstats_top_turnover_rate(index, topk=100):
        return data_pro.get_rainiee_client().cn_stockstats_top_turnover_rate(method_type='GET', req_param={
            'index': index,
            'topk': topk
        })

    @staticmethod
    def na_etf_stockstats_list(symbol):
        return data_pro.get_rainiee_client().na_etf_stockstats_list(method_type='GET', req_param={
            'symbol': symbol
        })

    @staticmethod
    def na_etf_stockstats_sort(column, start_date, end_date):
        return data_pro.get_rainiee_client().na_etf_stockstats_sort(method_type='GET', req_param={
            'column': column,
            'start_date': start_date if isinstance(start_date, str) else start_date.strftime('%Y%m%d'),
            'end_date': end_date if isinstance(end_date, str) else end_date.strftime('%Y%m%d')
        })

    @staticmethod
    def get_trade_index(date):
        return data_pro.get_rainiee_client().trade_get_index(method_type='GET', req_param={
            'date': date if isinstance(date, str) else date.strftime('%Y%m%d')})

    @staticmethod
    def get_trade_date(index):
        return data_pro.get_rainiee_client().trade_get_date(method_type='GET', req_param={
            'index': index
        })



#!/usr/bin/python
# -*- coding: UTF-8 -*-
import json

from rainiee_data_test.pro import data_pro


def cn_stockstats_latest_returns(symbol, gap=1):
    return data_pro.get_rainiee_client().cn_stockstats_latest_returns(method_type='GET', req_param={
        'symbol': symbol,
        'gap': gap
    })


def cn_stockstats_returns(symbol, start_index, end_index):
    return data_pro.get_rainiee_client().cn_stockstats_returns(method_type='GET', req_param={
        'symbol': symbol,
        'start_index': start_index,
        'end_index': end_index
    })


def cn_stockstats_returns_matrix(symbol_list, start_index, end_index):
    return data_pro.get_rainiee_client().cn_stockstats_returns_matrix(method_type='POST', req_param={
        'symbol_list': symbol_list,
        'start_index': start_index,
        'end_index': end_index
    })


def cn_stockstats_list(symbol, start_index, end_index):
    return data_pro.get_rainiee_client().cn_stockstats_list(method_type='GET', req_param={
        'symbol': symbol,
        'start_index': start_index,
        'end_index': end_index
    })


def cn_stockstats_sort(column, start_index, end_index):
    return data_pro.get_rainiee_client().cn_stockstats_sort(method_type='GET', req_param={
        'column': column,
        'start_index': start_index,
        'end_index': end_index
    })


def cn_stockstats_eod_portf_return(portf, hold_index):
    return data_pro.get_rainiee_client().cn_stockstats_eod_portf_return(method_type='POST', req_param={
        'portf': json.dumps(portf),
        'hold_index': hold_index
    })


def cn_stockstats_is_enter_market(index, return_metric, calc_period):
    return data_pro.get_rainiee_client().cn_stockstats_is_enter_market(method_type='GET', req_param={
        'index': index,
        'return_metric': return_metric,
        'calc_period': calc_period
    })


def cn_stockstats_top_turnover_rate(index, topk=100):
    return data_pro.get_rainiee_client().cn_stockstats_top_turnover_rate(method_type='GET', req_param={
        'index': index,
        'topk': topk
    })



#!/usr/bin/python
# -*- coding: UTF-8 -*-
from rainiee_data_test.pro import data_pro


def trade_execute_order(symbol, index, order_type, price):
    return data_pro.get_rainiee_client().trade_execute_order(method_type='GET', req_param={
        'symbol': symbol,
        'index': index,
        'order_type': order_type,
        'price': price
    })



import setuptools
import os
path = os.path.abspath(os.path.dirname(__file__))

try:
    with open(os.path.join(path, 'README.md'),encoding='utf8') as f:
        long_description = f.read()
except Exception as e:
    long_description = "rainiee stock test"

setuptools.setup(
    name="rainiee_data_test",
    version="2.2.0",
    author="rainiee",
    author_email="rainiee@163.com",
    description="rainiee stock data api",
    long_description = long_description,
    long_description_content_type='text/markdown',
    url="https://github.com/Rainiee-Technology/rainiee_data",
    license='MIT',
    zip_safe=False,
    packages=setuptools.find_packages(),
    python_requires='>=3',
)